@@ -1,4 +1,7 @@
 """
 This is the BAGUETTE framework. BAGUETTE stands for Behavioral Analysis Graph Using Execution Traces Towards Explanability.
 BAGUETTE is a heterogeneous graph data structure used to represent the behavior of malware samples.
-"""
\ No newline at end of file
+To learn how to use it quickly, simply type 'baguette.tutorial' in your terminal.
+"""
+
+__all__ = ["bakery", "croutons", "rack", "logger"]
\ No newline at end of file
