@@ -8,6 +8,7 @@ from typing import Any, Literal, TypeVar
 
 from .croutons.source.metagraph import MetaGraph
 from .bakery.source.filters import Filter
+from .bakery.source.graph import Graph
 from .bakery.source.colors import Color
 
 __all__ = ["BaguetteRack", "TimeoutExit"]
@@ -457,6 +458,23 @@ class BaguetteRack:
         if not list(self.working_directory.iterdir()):
             rmdir(self.working_directory)
 
+    def load(self) -> Graph:
+        """
+        Loads and returns the baguette associated to this graph.
+        """
+        if not self.baguette.exists():
+            raise FileNotFoundError("Baguette file does not exist")
+        if not self.baguette.is_file():
+            raise FileExistsError("Baguette path exists but is not a file")
+        from pickle import load
+        from baguette.bakery.source.graph import Graph
+        with self.baguette.open("rb") as f:
+            bag = load(f)
+            if not isinstance(bag, Graph):
+                raise RuntimeError("Given baguette file did not contain a BAGUETTE graph")
+            return bag
+
+
 
 
 
